@@ -2,10 +2,13 @@ import npyscreen
 
 
 class NotifForm(npyscreen.ActionFormMinimal):
+    """Display unread notification."""
+
     DEFAULT_COLUMNS = 60
     DEFAULT_LINES = 10
 
     def create(self):
+        """Create widgets."""
         self.name = "Notification"
         self.keypress_timeout = 1
         self.center_on_display()
@@ -15,9 +18,11 @@ class NotifForm(npyscreen.ActionFormMinimal):
         )
 
     def on_ok(self):
-        self.parentApp.state["notification"] = {}
+        """Mark notificaiton as read and back to previous form."""
+        self.parentApp.state.notification.read = True
         self.parentApp.setNextFormPrevious()
 
     def while_waiting(self):
-        self.text.value = self.parentApp.state["notification"].get("message")
+        """Set text value to notification content."""
+        self.text.value = self.parentApp.state.notification.content
         self.text.update()
